What can I do?
==============

EspressoDB aims to create projects fast.

In this section,

1. we want to present an example project and a few of EspressoDB's features.
2. we guide to the process which creates this project.

.. toctree::
    :caption: Contents:

    install
    public-views
    private-views
    external-scripts
